<h3>{t}Print Service{/t} {t}enabled{/t}</h3>

<hr>

<div class="plugin-actions">
 <button type='submit' name='SaveService'>{msgPool type=saveButton}</button>
 <button type='submit' name='CancelService'>{msgPool type=cancelButton}</button>
</div>
<input type="hidden" name="goCupsServerPosted" value="1">
